@@ -1,18 +1,17 @@
 package Perinci::Result::Format;
 
+our $DATE = '2015-02-24'; # DATE
+our $VERSION = '0.39'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
 
-use Scalar::Util qw(reftype);
-
-our $VERSION = '0.38'; # VERSION
-
 our $Enable_Decoration = 1;
 our $Enable_Cleansing  = 0;
 
 # text formats are special. since they are more oriented towards human instead
-# of machine, we remove envelope when status is 200, so users only see content.
+# of machine, we remove envelope when status is 2xx, so users only see content.
 
 # XXX color theme?
 
@@ -89,7 +88,7 @@ my $format_text = sub {
     };
 
     if (!defined($res->[2])) {
-        my $out = $res->[0] =~ /\A(?:200|304)\z/ ? "" : $print_err->($res);
+        my $out = $res->[0] =~ /\A(?:2..|304)\z/ ? "" : $print_err->($res);
         my $max = 30;
         my $i = 0;
         my $prev = $res;
@@ -106,15 +105,18 @@ my $format_text = sub {
         return $out;
     }
     my ($r, $opts);
-    if ($res->[0] == 200) {
+    if ($res->[0] =~ /\A2../) {
         $r = $res->[2];
         my $rfo = $res->[3]{result_format_options} // {};
-        # old compat, rfo used to be only opts, now it's {fmt=>opts, ...}
-        if ($rfo->{$format}) { $opts = $rfo->{$format} } else { $opts = $rfo }
+        if ($rfo->{$format}) {
+            $opts = $rfo->{$format};
+        } elsif ($rfo->{any}) {
+            $opts = $rfo->{any};
+        }
     } else {
         $r = $res;
-        $opts = {};
     }
+    $opts //= {};
     if ($format eq 'text') {
         return Data::Format::Pretty::format_pretty(
             $r, {%$opts, module=>'Console'});
@@ -163,7 +165,7 @@ sub format {
 
     my $deco = $Enable_Decoration;
 
-    if ((reftype($formatter) // '') eq 'CODE') {
+    if (ref($formatter) eq 'CODE') {
         return $formatter->($format, $res);
     } else {
         my %o;
@@ -188,7 +190,7 @@ Perinci::Result::Format - Format envelope result
 
 =head1 VERSION
 
-This document describes version 0.38 of Perinci::Result::Format (from Perl distribution Perinci-Result-Format), released on 2014-06-18.
+This document describes version 0.39 of Perinci::Result::Format (from Perl distribution Perinci-Result-Format), released on 2015-02-24.
 
 =head1 SYNOPSIS
 
@@ -323,7 +325,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Re
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Result-Format>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Result-Format>.
 
 =head1 BUGS
 
@@ -335,11 +337,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
